@@ -30,7 +30,7 @@ import random
 from adafruit_led_animation.color import BLACK
 from . import MS_PER_SECOND, monotonic_ms
 
-__version__ = "2.5.20"
+__version__ = "2.6.0"
 __repo__ = "https://github.com/adafruit/Adafruit_CircuitPython_LED_Animation.git"
 
 
@@ -179,6 +179,13 @@ class AnimationSequence:
             self.on_cycle_complete()
         self.activate(current % len(self._members))
 
+    def previous(self):
+        """
+        Jump to the previous animation.
+        """
+        current = self._current - 1
+        self.activate(current % len(self._members))
+
     def random(self):
         """
         Jump to a random animation.
